#
# spec file for package perl-EV
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-EV
Version:        4.22
Release:        1.7
#Upstream: CHECK(GPL-1.0+ or Artistic-1.0)
%define cpan_name EV
Summary:        Perl Interface to Libev, a High Performance Full-Featured Event Loop
License:        GPL-2.0+ or BSD-2-Clause
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/EV/
Source0:        http://www.cpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
Source1:        rpmlintrc
Source2:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Canary::Stability)
BuildRequires:  perl(common::sense)
Requires:       perl(common::sense)
%{perl_requires}

%description
This module provides an interface to libev
(http://software.schmorp.de/pkg/libev.html). While the documentation below
is comprehensive, one might also consult the documentation of libev itself
(http://pod.tst.eu/http://cvs.schmorp.de/libev/ev.pod or _perldoc
EV::libev_) for more subtle details on watcher semantics or some discussion
on the available backends, or how to force a specific backend with
'LIBEV_FLAGS', or just about in any case because it has much more detailed
information.

This module is very fast and scalable. It is actually so fast that you can
use it through the AnyEvent module, stay portable to other event loops (if
you don't rely on any watcher types not available through it) and still be
faster than with any other event loop currently supported in Perl.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes COPYING README

%changelog
* Sat Dec 26 2015 coolo@suse.com
- updated to 4.22
  see /usr/share/doc/packages/perl-EV/Changes
* Sun Sep 20 2015 coolo@suse.com
- updated to 4.21
  see /usr/share/doc/packages/perl-EV/Changes
* Fri Apr 17 2015 coolo@suse.com
- updated to 4.18
  see /usr/share/doc/packages/perl-EV/Changes
  4.18 Sat Sep  6 20:37:23 CEST 2014
  - use slightly better weay to find includes, to support multiarch
    on newer perls.
  4.17 Fri Apr 11 06:22:38 CEST 2014
  - perl5porters broke Async::Interrupt, BDB, EV, IO::AIO, OpenCL
    without warning by switching the meaning of USE_SOCKETS_AS_HANDLES
    in 5.18. What's so attractive about giving a shit about backwards
    compatibility - I will never understand.
  4.16 Sat Mar  8 16:49:05 CET 2014
  - make sure EV::CHECK is available at all times.
  - avoid a spurious warning when perl -w overrides "no warnings".
  - use perl's signal implementation on WIN32.
  - ensure extern "C" function pointers are used for externally-visible
    pointers.
  - (libev) mark event pipe fd as cloexec after a fork (analyzed by Sami Farin).
  - (ecb) support m68k, m88k and sh (patch by Miod Vallat).
  - (libev) in the absence of autoconf, do not use the clock syscall
    on glibc >= 2.17 (avoids the syscall AND -lrt on systems
    doing clock_gettime in userspace).
  - (ecb) work around memory barriers and volatile apparently both being
    broken in visual studio 2008 and later (analysed and patch by Nicolas Noble).
  4.15 Fri Mar  1 12:15:53 CET 2013
  - (libev) upgrade to 4.15 - too many changes to list.
  - EV::run now returns a boolean.
  - API version 5:1.
  - document that cleanup watchers are not available via perl.
  - cast I32 to int in error message printf.
  - remove dependencies on librt and libpthreads on GNU/Linux.
  4.11 Sat Feb  4 19:56:26 CET 2012
  - (libev) implement memory fences for (obsolete) llvm-gcc.
  4.10 Thu Jan 19 18:54:23 CET 2012
  - (libev) fix a race where the workaround against the epoll fork
    bugs caused signals to not be handled anymore.
  - (libev) correct backend_fudge for most backends, and implement
    a windows specific workaround to avoid looping because we call
    both select and Sleep, both with different time resolutions.
  - e_new wasn't declared static (causing very minor .so bloat).
  - replace more old api names by new ones.
* Fri Mar  4 2011 chris@computersalat.de
- update to 4.03
  - do not avoid the clock_gettime call on GNU/Linux anymore, as EV
    links against -lpthread anyways - as a result, EV might now take
    advantage of fast userspace clock_gettime implementations,
    but also links against -lrt.
  - (libev) lots of event port bug workarounds.
  - (libev) officially support files in I/O watchers.
  - (libev) new function ev_feed_signal.
  - fix documentation parts still refering to the 3.x API.
- 4.02 Thu Dec 30 08:27:41 CET 2010
  - the revents argument did not stringify correctly, as only the
    numeric value was updated, while the string value was kept from
    previous invocations.
- 4.01 Sun Dec  5 12:42:13 CET 2010
  - fully support EV_COMPAT3=0.
  - default_fork was stupidly defined as inline.
  - ask cpan to upgrade AnyEvent if < 5.29.
  - support EV_EXTRA_DEFS during configuration.
  - support -DEV_NO_LOOPS for snakker build.
- 4.00 Mon Oct 25 13:30:09 CEST 2010
  - many API changes, see the manual.
  - (libev) lots and lots of bugfixes, see the ev documentation.
  - fix a bug where inotify usage would parse the same event
    multiple times, causing various forms of breakage.
  - greatly reduce stack usage for inotify (8kb to <0.5kb).
  - expose ev_depth and ev_verify via the XS API.
  - implement ev_cleanup watchers.
  - (libev) ev_embed_stop did not correctly stop the watcher.
  - (libev) disable poll backend on AIX.
  - (libev) rename EV_TIMEOUT to EV_TIMER.
  - (libev) add section on accept() problems to the manpage.
  - (libev) no child watchers on win32.
  - make code more aliasing compliant, in case perl is ever
    translated to C.
  - document the EV::CHECK runtime unavailability.
  - ported to minix 3.1.7.
- split package
  o <= 3.9 perl-EV_3
  o >= 4 perl-EV
- added rpmlintrc
  o devel-file-in-non-devel-package
* Fri Mar  4 2011 chris@computersalat.de
- update to 3.9
  - disable t/07* under automatic testing.
  - increase t/09* timeouts as netbsd has *horribly* broken
    select/kevent that *usually* sleep >>0.6s instead of 0.3.
  - add constants EV::FLAG_NOSIGFD, EV::FLAG_NOINOTIFY and
    EV::BACKEND_ALL.
  - (libev) signalfd is no longer used by default.
  - (libev) backport inotify code to C89.
  - (libev) inotify file descriptors could leak into child processes.
  - (libev) ev_stat watchers could keep an errornous extra ref on the loop.
  - (libev) take advantage of inotify_init1, if available.
  - (libev) the signal handling pipe wasn't always initialised under windows.
  - changed minimum glibc requirement from glibc 2.9 to 2.7, for signalfd.
  - (libev) only replace ev_stat.prev when we detect an actual difference.
- recreated by cpanspec 1.78.03
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Sep  4 2009 chris@computersalat.de
- initial pkg 3.8
